.. change::
    :tags: bug, sql
    :tickets: 11471
    :versions: 2.0.31

    Fixed caching issue where using the :meth:`.TextualSelect.add_cte` method
    of the :class:`.TextualSelect` construct would not set a correct cache key
    which distinguished between different CTE expressions.
